@@ -60,7 +60,7 @@ CodeReviewSummaryTypeDef = TypedDict(
         "CodeReviewArn": str,
         "RepositoryName": str,
         "Owner": str,
-        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket"],
+        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket", "GitHubEnterpriseServer"],
         "State": Literal["Completed", "Pending", "Failed", "Deleting"],
         "CreatedTimeStamp": datetime,
         "LastUpdatedTimeStamp": datetime,
@@ -78,7 +78,7 @@ CodeReviewTypeDef = TypedDict(
         "CodeReviewArn": str,
         "RepositoryName": str,
         "Owner": str,
-        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket"],
+        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket", "GitHubEnterpriseServer"],
         "State": Literal["Completed", "Pending", "Failed", "Deleting"],
         "StateReason": str,
         "CreatedTimeStamp": datetime,
@@ -143,7 +143,7 @@ RepositoryAssociationSummaryTypeDef = TypedDict(
         "AssociationId": str,
         "Name": str,
         "Owner": str,
-        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket"],
+        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket", "GitHubEnterpriseServer"],
         "State": Literal["Associated", "Associating", "Failed", "Disassociating"],
     },
     total=False,
@@ -157,7 +157,7 @@ RepositoryAssociationTypeDef = TypedDict(
         "ConnectionArn": str,
         "Name": str,
         "Owner": str,
-        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket"],
+        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket", "GitHubEnterpriseServer"],
         "State": Literal["Associated", "Associating", "Failed", "Disassociating"],
         "StateReason": str,
         "LastUpdatedTimeStamp": datetime,
@@ -238,6 +238,10 @@ PaginatorConfigTypeDef = TypedDict(
 
 RepositoryTypeDef = TypedDict(
     "RepositoryTypeDef",
-    {"CodeCommit": "CodeCommitRepositoryTypeDef", "Bitbucket": "ThirdPartySourceRepositoryTypeDef"},
+    {
+        "CodeCommit": "CodeCommitRepositoryTypeDef",
+        "Bitbucket": "ThirdPartySourceRepositoryTypeDef",
+        "GitHubEnterpriseServer": "ThirdPartySourceRepositoryTypeDef",
+    },
     total=False,
 )
